@@ -341,7 +341,7 @@ int TryInsertArchiveDirEntry(DirEntry *tree, char *dir, struct stat *stat)
 
 
 
-int MinimizeArchiveTree(DirEntry *tree)
+void MinimizeArchiveTree(DirEntry *tree)
 {
   DirEntry  *de_ptr, *de1_ptr;
   DirEntry  *next_ptr;
@@ -428,7 +428,7 @@ int MinimizeArchiveTree(DirEntry *tree)
       de1_ptr->up_tree = tree;
     free( de_ptr );
   }
-  return( 0 );
+  return;
 }
 
 
@@ -479,6 +479,30 @@ void MakeExtractCommandLine(char *command_line, char *path, char *file, char *cm
 		    cmd
 		  );
   }
+  else if( compress_method == SEVENZIP_COMPRESS )
+  {
+    /* 7z x FILE ?? */
+    /*--------------*/
+
+    (void) sprintf( command_line, "%s '%s' '%s' %s", 
+		    SEVENZIPEXPAND,
+		    path,
+		    file,
+		    cmd
+		  );
+  }
+  else if( compress_method == ISO_COMPRESS )
+  {
+    /* 7z x FILE ?? */
+    /*--------------*/
+
+    (void) sprintf( command_line, "%s '%s' '%s' %s", 
+		    ISOEXPAND,
+		    path,
+		    file,
+		    cmd
+		  );
+  }
   else if( compress_method == ARC_COMPRESS )
   {
     /* arc p FILE ?? */
@@ -630,6 +654,32 @@ void MakeExtractCommandLine(char *command_line, char *path, char *file, char *cm
 		    cmd
 		  );
   }
+  else if( compress_method == ZSTD_COMPRESS )
+  {
+    /* zstdcat < TAR_FILE | gtar xOf - FILE ?? */
+    /*----------------------------------------*/
+
+    (void) sprintf( command_line, "%s < '%s' | %s '%s' %s",
+		    ZSTDCAT, 
+		    path,
+		    TAREXPAND,
+		    file,
+		    cmd
+		  );
+  }
+  else if( compress_method == LZIP_COMPRESS )
+  {
+    /* lzip -cd < TAR_FILE | gtar xOf - FILE ?? */
+    /*----------------------------------------*/
+
+    (void) sprintf( command_line, "%s < '%s' | %s '%s' %s",
+		    LUNZIP, 
+		    path,
+		    TAREXPAND,
+		    file,
+		    cmd
+		  );
+  }
   else
   {
     /* gtar xOf - FILE < TAR_FILE ?? */
