@@ -27,6 +27,8 @@
 #define DEFAULT_UNCOMPRESS "uncompress"
 #define DEFAULT_GNUUNZIP   "gunzip -c"
 #define DEFAULT_BUNZIP     "bunzip2"
+#define DEFAULT_ZSTDCAT    "zstdcat"
+#define DEFAULT_LUNZIP     "lzip -dc"
 #define DEFAULT_MANROFF    "nroff -man"
 
 #define DEFAULT_ZOOLIST    "zoo vm"
@@ -35,6 +37,12 @@
 #define DEFAULT_ZIPLIST    "zipinfo -l"
 #define DEFAULT_ZIPEXPAND  "unzip -p"
 
+#define DEFAULT_7zLIST     "7z l"
+#define DEFAULT_7zEXPAND   "7z -so x"
+
+#define DEFAULT_ISOLIST     "7z l"
+#define DEFAULT_ISOEXPAND   "7z -so x"
+
 #define DEFAULT_LHALIST    "xlharc v"
 #define DEFAULT_LHAEXPAND  "xlharc p"
 
