@@ -62,6 +62,13 @@ static void BuildDirEntryList(DirEntry *dir_entry)
 
   total_dirs = current_dir_entry;
 
+#ifdef DEBUG
+  if(statistic.disk_total_directories != total_dirs)
+  {
+    ERROR_MSG( "directory count mismatch" );
+  }
+#endif  
+
 }
 
 static void RotateDirMode(void)
