@@ -80,6 +80,14 @@ static char *dir_help[MAX_MODES][2] =
       "ZIP-DIR   (F)ilespec (L)og (S)howall (T)ag (U)ntag e(X)ecute   (^F) dirmode  (Q)uit         ",
       "COMMANDS                                                                    "
     },
+    { /* SEVENZIP_FILE_MODE */
+      "7z-DIR    (F)ilespec (L)og (S)howall (T)ag (U)ntag e(X)ecute   (^F) dirmode  (Q)uit         ",
+      "COMMANDS                                                                    "
+    },
+    { /* ISO_FILE_MODE */
+      "ISO-DIR   (F)ilespec (L)og (S)howall (T)ag (U)ntag e(X)ecute   (^F) dirmode  (Q)uit         ",
+      "COMMANDS                                                                    "
+    },
     { /* LHA_FILE_MODE */
       "LHA-DIR   (F)ilespec (L)og (S)howall (T)ag (U)ntag e(X)ecute   (^F) dirmode  (Q)uit         ",
       "COMMANDS                                                                    "
@@ -131,6 +139,14 @@ static char *file_help[MAX_MODES][2] =
       "ZIP-FILE  (C)opy (F)ilespec (H)ex (P)ipe (S)ort (T)ag (U)ntag (V)iew pathcop(Y) (Q)uit         ",
       "COMMANDS  (^F)ilemode                                                        "
     },
+    { /* SEVENZIP_FILE_MODE */
+      "7z-FILE  (C)opy (F)ilespec (H)ex (P)ipe (S)ort (T)ag (U)ntag (V)iew pathcop(Y) (Q)uit         ",
+      "COMMANDS  (^F)ilemode                                                        "
+    },
+    { /* ISO_FILE_MODE */
+      "ISO-FILE  (C)opy (F)ilespec (H)ex (P)ipe (S)ort (T)ag (U)ntag (V)iew pathcop(Y) (Q)uit         ",
+      "COMMANDS  (^F)ilemode                                                        "
+    },
     { /* LHA_FILE_MODE */
       "LHA-FILE  (C)opy (F)ilespec (H)ex (P)ipe (S)ort (T)ag (U)ntag (V)iew pathcop(Y) (Q)uit         ",
       "COMMANDS  (^F)ilemode                                                        "
