@@ -22,7 +22,7 @@ static int  PrintMessage(char *msg, BOOL do_beep);
 void Message(char *msg)
 {
   MapErrorWindow( "E R R O R" );
-  (void) PrintMessage( msg, true );
+  (void) PrintMessage( msg, TRUE );
 }
 
 
@@ -38,7 +38,7 @@ void Notice(char *msg)
 void Warning(char *msg)
 {
   MapErrorWindow( "W A R N I N G" );
-  (void) PrintMessage( msg, true );
+  (void) PrintMessage( msg, TRUE );
 }
 
 
@@ -47,13 +47,17 @@ void AboutBox()
   static char version[80];
   
   (void) sprintf( version, 
+#ifdef WITH_UTF8
+                  "ytree (UTF8) Version %s %s*(Werner Bregulla)", 
+#else
                   "ytree Version %s %s*(Werner Bregulla)", 
+#endif
                   VERSION, 
                   VERSIONDATE 
                 );
 
   MapErrorWindow( "ABOUT" );
-  (void) PrintMessage( version, false );
+  (void) PrintMessage( version, FALSE );
 }
 
 
@@ -65,7 +69,7 @@ void Error(char *msg, char *module, int line)
   (void) sprintf( buffer, "%s*In Module \"%s\"*Line %d", 
 		  msg, module, line
 		);
-  (void) PrintMessage( buffer, true );
+  (void) PrintMessage( buffer, TRUE );
 }
 
 
