@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/filespec.c,v 1.12 2004/03/21 14:13:11 werner Exp $
  *
  * Setzt neue Datei-Spezifikation
  *
@@ -83,7 +81,7 @@ int ReadFileSpec(void)
 {
   int result = -1;
 
-  char buffer[FILE_SPEC_LENGTH + 1];
+  char buffer[FILE_SPEC_LENGTH * 2 + 1];
 
   ClearHelp();
 
