@@ -51,15 +51,15 @@ static int  SortByGroup(FileEntryList *e1, FileEntryList *e2);
 static int  SortByExtension(FileEntryList *e1, FileEntryList *e2);
 static void DisplayFiles(DirEntry *de_ptr, int start_file_no, int hilight_no, int start_x);
 static void ReadGlobalFileList(BOOL tagged_only, DirEntry *dir_entry);
-static void WalkTaggedFiles(int start_file, int cursor_pos, int (*fkt) (/* ??? */), WalkingPackage *walking_package);
+static void WalkTaggedFiles(int start_file, int cursor_pos, int (*fkt) (FileEntry *, WalkingPackage *), WalkingPackage *walking_package);
 static BOOL IsMatchingTaggedFiles(void);
 static void RemoveFileEntry(int entry_no);
 static void ChangeFileEntry(void);
 static int  DeleteTaggedFiles(int max_dispfiles);
-static void SilentWalkTaggedFiles( int (*fkt) (/* ??? */), 
+static void SilentWalkTaggedFiles( int (*fkt) (FileEntry *, WalkingPackage *),
 			           WalkingPackage *walking_package
 			          );
-static void SilentTagWalkTaggedFiles( int (*fkt) (/* ??? */), 
+static void SilentTagWalkTaggedFiles( int (*fkt) (FileEntry *, WalkingPackage *),
 			           WalkingPackage *walking_package
 			          );
 static void RereadWindowSize(DirEntry *dir_entry);
@@ -238,7 +238,7 @@ static void ReadGlobalFileList(BOOL tagged_only, DirEntry *dir_entry)
 static void SortFileEntryList(void)
 {
   int aux;
-  int (*compare)();
+  int (*compare)(FileEntryList *, FileEntryList *);
 
   reverse_sort = FALSE;
   if ((aux = statistic.kind_of_sort) > SORT_DSC)
@@ -267,7 +267,7 @@ static void SortFileEntryList(void)
   qsort( (char *) file_entry_list, 
 	 file_count,
 	 sizeof( file_entry_list[0] ),
-	 compare
+	 (int (*)(const void *, const void *)) compare
 	);
 }
 
@@ -2501,7 +2501,9 @@ int HandleFileWindow(DirEntry *dir_entry)
       case 'l':
 #endif /* VI_KEYS */
       case 'L':      fe_ptr = file_entry_list[dir_entry->start_file + dir_entry->cursor_pos].file;
-		     if( mode == DISK_MODE || mode == USER_MODE )
+		     if( mode 
+         
+         == DISK_MODE || mode == USER_MODE )
 		     {
 		       (void) GetFileNamePath( fe_ptr, new_login_path );
                        if( !GetNewLoginPath( new_login_path ) )
@@ -2764,7 +2766,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 
 static void WalkTaggedFiles(int start_file, 
 			    int cursor_pos, 
-			    int (*fkt) (/* ??? */), 
+			    int (*fkt) (FileEntry *, WalkingPackage *),
 			    WalkingPackage *walking_package
 			   )
 {
@@ -2854,7 +2856,7 @@ static void WalkTaggedFiles(int start_file,
  --crb3 12mar04
 */
 
-static void SilentWalkTaggedFiles( int (*fkt) (/* ??? */), 
+static void SilentWalkTaggedFiles( int (*fkt) (FileEntry *, WalkingPackage *),
 			           WalkingPackage *walking_package
 			          )
 {
@@ -2889,7 +2891,7 @@ ExecuteCommand must have its retval unzeroed.
 
 */ 
 
-static void SilentTagWalkTaggedFiles( int (*fkt) (/* ??? */), 
+static void SilentTagWalkTaggedFiles( int (*fkt) (FileEntry *, WalkingPackage *),
 			           WalkingPackage *walking_package
 			          )
 {
