@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/freesp.c,v 1.24 2007/06/04 16:58:03 werner Exp $
  *
  * Ermittlung der freien Plattenkapazitaet
  *
@@ -9,7 +7,7 @@
 
 #include "ytree.h"
 
-#if ( defined( linux ) || defined( sun ) || defined( __NeXT__ )  || defined(hpux) || defined ( __FreeBSD__ ) || defined( __DJGPP__ ) || defined ( __GNU__ ) ) && !defined( SVR4 )
+#if ( defined( linux ) || defined( sun ) || defined( __NeXT__ )  || defined(hpux) || defined( __DJGPP__ ) || defined ( __GNU__ ) ) && !defined( SVR4 )
 
 #include <sys/vfs.h>
 #else
