@@ -124,14 +124,16 @@ int LoginDisk(char *path)
   (void) strcpy( statistic.file_spec, DEFAULT_FILE_SPEC );
   (void) strcpy( statistic.tape_name, DEFAULT_TAPEDEV );
   statistic.kind_of_sort = SORT_BY_NAME + SORT_ASC;
-  (void) memcpy( &statistic.tree->stat_struct, 
-		 &stat_struct, 
-		 sizeof( stat_struct ) 
-	       );
+  (void) memcpy( &statistic.tree->stat_struct, &stat_struct, sizeof( stat_struct ) );
   
  
   if( !S_ISDIR(stat_struct.st_mode ) )
   {
+    /* "root" node is always a directory */
+    (void) memset( (char *) &statistic.tree->stat_struct, 0, sizeof( struct stat ) );
+    statistic.tree->stat_struct.st_mode = S_IFDIR;
+    statistic.disk_total_directories = 1;
+
     /* No Directory ==> TAR_FILE/RPM/ZOO/ZIP/LHA/ARC_FILE */
     /*----------------------------------------------------*/
 
@@ -140,19 +142,21 @@ int LoginDisk(char *path)
 
     switch( file_method )
     {
-      case ZOO_COMPRESS:    mode = ZOO_FILE_MODE; break;
-      case ARC_COMPRESS:    mode = ARC_FILE_MODE; break;
-      case LHA_COMPRESS:    mode = LHA_FILE_MODE; break;
-      case ZIP_COMPRESS:    mode = ZIP_FILE_MODE; break;
-      case RPM_COMPRESS:    mode = RPM_FILE_MODE; break;
-      case RAR_COMPRESS:    mode = RAR_FILE_MODE; break;
+      case ZOO_COMPRESS:         mode = ZOO_FILE_MODE; break;
+      case ARC_COMPRESS:         mode = ARC_FILE_MODE; break;
+      case LHA_COMPRESS:         mode = LHA_FILE_MODE; break;
+      case ZIP_COMPRESS:         mode = ZIP_FILE_MODE; break;
+      case SEVENZIP_COMPRESS:    mode = SEVENZIP_FILE_MODE; break;
+      case ISO_COMPRESS:         mode = ISO_FILE_MODE; break;
+      case RPM_COMPRESS:         mode = RPM_FILE_MODE; break;
+      case RAR_COMPRESS:         mode = RAR_FILE_MODE; break;
       case TAPE_DIR_NO_COMPRESS:
       case TAPE_DIR_COMPRESS_COMPRESS:
       case TAPE_DIR_FREEZE_COMPRESS:
       case TAPE_DIR_GZIP_COMPRESS:
       case TAPE_DIR_BZIP_COMPRESS:
-                            mode = TAPE_MODE;     break;
-      default:              mode = TAR_FILE_MODE; break;
+                                 mode = TAPE_MODE;     break;
+      default:                   mode = TAR_FILE_MODE; break;
     }
   }
   else if (IsUserActionDefined())
@@ -240,6 +244,26 @@ int LoginDisk(char *path)
 		      statistic.login_path
 		    );
     } 
+    else if( file_method == SEVENZIP_COMPRESS )
+    {
+      /* 7z_FILE */
+      /*---------*/
+    
+      (void) sprintf( command_line, "%s '%s'", 
+		      SEVENZIPLIST, 
+		      statistic.login_path
+		    );
+    } 
+    else if( file_method == ISO_COMPRESS )
+    {
+      /* ISO_FILE */
+      /*----------*/
+    
+      (void) sprintf( command_line, "%s '%s'", 
+		      ISOLIST, 
+		      statistic.login_path
+		    );
+    } 
     else if( file_method == ARC_COMPRESS )
     {
       /* ARC_FILE */
@@ -356,6 +380,30 @@ int LoginDisk(char *path)
 		      TARLIST
 		    );
     }
+    else if( file_method == ZSTD_COMPRESS )
+    {
+      /* zstdcat < TAR_FILE | gtar tvf - */
+      /*---------------------------------*/
+    
+      (void) sprintf( command_line, "%s < '%s' %s | %s", 
+		      ZSTDCAT, 
+		      statistic.login_path,
+		      ERR_TO_STDOUT,
+		      TARLIST
+		    );
+    }
+    else if( file_method == LZIP_COMPRESS )
+    {
+      /* lzip -dc < TAR_FILE | gtar tvf - */
+      /*----------------------------------*/
+    
+      (void) sprintf( command_line, "%s < '%s' %s | %s", 
+		      LUNZIP, 
+		      statistic.login_path,
+		      ERR_TO_STDOUT,
+		      TARLIST
+		    );
+    }
     else if( file_method == NO_COMPRESS )
     {
       /* NO_COMPRESS */
@@ -478,7 +526,27 @@ int LoginDisk(char *path)
 	return( -1 );
       }
       
-      if( mode == ZOO_FILE_MODE )
+      if( mode == ISO_FILE_MODE )
+      {
+	      if( ReadTreeFrom7z( statistic.tree, f ) )  /* same as 7z */
+        {
+	        ERROR_MSG( "ReadTreeFromISO Failed" );
+          (void) fclose( f );
+	        (void) wait( &status );
+          return( -1 );
+        }
+      }
+      if( mode == SEVENZIP_FILE_MODE )
+      {
+	      if( ReadTreeFrom7z( statistic.tree, f ) )
+        {
+	        ERROR_MSG( "ReadTreeFrom7z Failed" );
+          (void) fclose( f );
+	        (void) wait( &status );
+          return( -1 );
+        }
+      }
+      else if( mode == ZOO_FILE_MODE )
       {
 	if( ReadTreeFromZOO( statistic.tree, f ) )
         {
@@ -612,7 +680,7 @@ int GetNewLoginPath(char *path)
     if( aux[strlen(aux) - 1] == '>' ) aux[strlen(aux) - 1 ] = '\0';
   }
 
-  if( InputString( aux, LINES - 2, 17, 0, COLS - 24, "\r\033" ) == CR )
+  if( InputString( aux, LINES - 2, 17, 0, COLS - 18, "\r\033" ) == CR )
   {
     NormPath(aux, path);
     result = 0;
