@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/main.c,v 1.19 2005/09/07 18:50:33 werner Exp $
  *
  * Hauptmodul
  *
@@ -22,7 +20,7 @@ int main(int argc, char **argv)
   char *hist;
   char *conf;
 
-#ifndef sun
+#if (!defined(sun) && !defined(__DJGPP__))
   setlocale(LC_ALL, "");
 #endif
 
