@@ -7,19 +7,15 @@
 
 #include "ytree.h"
 
-#if defined( sun ) || defined( linux ) || defined( __NeXT__ ) || defined( OSF1 ) ||  defined( __OpenBSD__ ) || defined(__NetBSD__) || defined( __FreeBSD__ ) || defined( __GNU__ )
+
+#if defined( hpux ) || defined ( __APPLE__ ) || defined ( linux )
+#define HAS_REGCOMP
+#else
+#if defined( sun ) || defined( __NeXT__ ) || defined( OSF1 ) ||  defined( __OpenBSD__ ) || defined(__NetBSD__) || defined( __FreeBSD__ ) || defined( __GNU__ )
 #define HAS_REGEX
 #endif
-
-#ifdef linux
-/* To avoid warning about re_comp / re_exec */
-/* Maybe this would work on other architectures too */
-#define _REGEX_RE_COMP
 #endif
 
-#if defined( hpux ) || defined ( __APPLE__ )
-#define HAS_REGCOMP
-#endif
 
 
 #ifdef HAS_REGEX
@@ -37,8 +33,6 @@
 #else
 extern char *regcmp();
 extern char *regex();
-static char *file_spec_cmp = NULL;
-
 #endif /* HAS_REGEX */
 
 #if defined( HAS_REGCOMP )
@@ -47,13 +41,17 @@ static regex_t	re;
 static BOOL	re_flag = FALSE;
 #endif
 
+#if ( !defined(HAS_REGEX) && !defined(HAS_REGCOMP) && !(defined(WIN32) || defined(__DJGPP__)) )
+static char *file_spec_cmp = NULL;
+#endif
+
+
 
 
 
 
 int SetMatchSpec(char *new_spec)
 {
-  char *result;
   char *buffer;
   char *b_ptr;
   BOOL meta_flag = FALSE;
@@ -95,7 +93,7 @@ int SetMatchSpec(char *new_spec)
 
 #if defined ( HAS_REGEX )
 
-  if( ( result = (char *) re_comp( buffer ) ) )
+  if( re_comp( buffer ) )
   {
     free( buffer );
     return( 1 );
@@ -123,18 +121,21 @@ int SetMatchSpec(char *new_spec)
 
 #if (!(defined(WIN32) || defined(__DJGPP__)))
 
-
-  if( ( result = regcmp( buffer, (char *) 0 ) ) == NULL )
   {
+    char *result;
+
+    if( ( result = regcmp( buffer, (char *) 0 ) ) == NULL )
+    {
+      free( buffer );
+      return( 1 );
+    }
+  
+    if( file_spec_cmp ) free( file_spec_cmp );
     free( buffer );
-    return( 1 );
+  
+    file_spec_cmp = result;
   }
 
-  if( file_spec_cmp ) free( file_spec_cmp );
-  free( buffer );
-
-  file_spec_cmp = result;
-
 #else
 
   /* WIN32 */
@@ -142,7 +143,6 @@ int SetMatchSpec(char *new_spec)
   /* z.Z. nicht unterstuetzt */
 
   free( buffer );
-  result = 0;
 
 #endif /* WIN32 */
 #endif /* HAS_REGCOMP */
