@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/move.c,v 1.15 2005/01/22 16:32:29 werner Exp $
  *
  * Beschreibung : Bewegen von Dateien
  *
@@ -81,7 +79,10 @@ int MoveFile(FileEntry *fe_ptr,
       {
 	term = InputChoise( "file exist; overwrite (Y/N) ? ", "YN\033" );
     
-        if( term != 'Y' ) ESCAPE;
+        if( term != 'Y' ) {
+	  result = (term == 'N' ) ? 0 : -1;  /* Abort on escape */
+	  ESCAPE;
+	}
       }
 
       (void) DeleteFile( dest_file_entry );
@@ -101,7 +102,10 @@ int MoveFile(FileEntry *fe_ptr,
       {
 	term = InputChoise( "file exist; overwrite (Y/N) ? ", "YN\033" );
       
-        if( term != 'Y' ) ESCAPE;
+        if( term != 'Y' ) {
+	  result = (term == 'N' ) ? 0 : -1;  /* Abort on escape */
+	  ESCAPE;
+	}
       }
         
       if( unlink( to_path ) )
