@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/print.c,v 1.2 1998/05/10 20:02:24 werner Rel $
  *
  * Enhanced Curses Functions
  *
@@ -14,30 +12,57 @@
 
 int MvAddStr(int y, int x, char *str)
 {
+#ifdef WITH_UTF8
+  mvaddstr(y, x, str);
+#else
   for(;*str != '\0';str++)
       mvaddch(y, x++, PRINT(*str));
+#endif
   return 0;
 }
 
 int MvWAddStr(WINDOW *win, int y, int x, char *str)
 {
+#ifdef WITH_UTF8
+  mvwaddstr(win, y, x, str);
+#else
   for(;*str != '\0';str++)
       mvwaddch(win, y, x++, PRINT(*str));
+#endif
   return 0;
 }
 
 
 int WAddStr(WINDOW *win, char *str)
 {
+#ifdef WITH_UTF8
+  waddstr(win, str);
+#else
   for(;*str != '\0';str++)
       waddch(win, PRINT(*str));
+#endif
   return 0;
 }
 
 int AddStr(char *str)
 {
+#ifdef WITH_UTF8
+  addstr(str);
+#else
   for(;*str != '\0';str++)
       addch( PRINT(*str));
+#endif
   return 0;
 }
 
+int WAttrAddStr(WINDOW *win, int attr, char *str)
+{
+  int rc; 
+
+  wattrset( win, attr );
+  rc = WAddStr(win, str);
+  wattrset( win, 0 );
+
+  return(rc);
+}
+
