@@ -52,8 +52,10 @@ static Viewer viewer;
 static Dirmenu dirmenu;
 static Filemenu filemenu;
 
-/* MUSS sortiert sein! */
+/* must be sorted! */
 static Profile profile[] = { 
+  { "7zEXPAND",       DEFAULT_7zEXPAND,      NULL,     NULL },
+  { "7zLIST",       	DEFAULT_7zLIST,        NULL,     NULL },
   { "ARCEXPAND",    	DEFAULT_ARCEXPAND,     NULL,     NULL },
   { "ARCLIST",      	DEFAULT_ARCLIST,       NULL,     NULL },
   { "BUNZIP",       	DEFAULT_BUNZIP,        NULL,     NULL },
@@ -68,9 +70,12 @@ static Profile profile[] = {
   { "HEXDUMP",      	DEFAULT_HEXDUMP,       NULL,     NULL },
   { "HEXEDITOFFSET",	DEFAULT_HEXEDITOFFSET, NULL,     NULL },
   { "INITIALDIR",   	DEFAULT_INITIALDIR,    NULL,     NULL },
+  { "ISOEXPAND",       	DEFAULT_ISOEXPAND,     NULL,     NULL },
+  { "ISOLIST",       	DEFAULT_ISOLIST,       NULL,     NULL },
   { "LHAEXPAND",    	DEFAULT_LHAEXPAND,     NULL,     NULL },
   { "LHALIST",      	DEFAULT_LHALIST,       NULL,     NULL },
   { "LISTJUMPSEARCH",   DEFAULT_LISTJUMPSEARCH,NULL,     NULL },
+  { "LUNZIP",           DEFAULT_LUNZIP,        NULL,     NULL },
   { "MANROFF",      	DEFAULT_MANROFF,       NULL,     NULL },
   { "MELT",         	DEFAULT_MELT,          NULL,     NULL },
   { "NOSMALLWINDOW",	DEFAULT_NOSMALLWINDOW, NULL,     NULL },
@@ -90,7 +95,8 @@ static Profile profile[] = {
   { "ZIPEXPAND",    	DEFAULT_ZIPEXPAND,     NULL,     NULL },
   { "ZIPLIST",      	DEFAULT_ZIPLIST,       NULL,     NULL },
   { "ZOOEXPAND",    	DEFAULT_ZOOEXPAND,     NULL,     NULL },
-  { "ZOOLIST",      	DEFAULT_ZOOLIST,       NULL,     NULL }
+  { "ZOOLIST",      	DEFAULT_ZOOLIST,       NULL,     NULL },
+  { "ZSTDCAT",      	DEFAULT_ZSTDCAT,       NULL,     NULL }
 };
 
 #define PROFILE_ENTRIES (sizeof(profile) / sizeof(profile[0]))
