@@ -75,7 +75,7 @@ void DisplayDirStatistic(DirEntry *dir_entry)
   (void) GetPath( dir_entry, statistic.path );
   if (dir_entry -> not_scanned)
      strcat(statistic.path,"*");
-  sprintf(auxbuff, format, FormFilename( buffer, statistic.path, COLS - 10 ));
+  sprintf(auxbuff, format, FormFilename( buffer, statistic.path, MAXIMUM(COLS - 10, 0)));
   wmove( stdscr, 0, 6);
   wclrtoeol( stdscr);
   Print( stdscr, 0, 6, auxbuff, HIMENUS_COLOR);
@@ -131,7 +131,7 @@ void DisplayDirParameter(DirEntry *dir_entry)
   (void) GetPath( dir_entry, statistic.path );
   if (dir_entry -> not_scanned)
      strcat(statistic.path,"*");
-  sprintf(auxbuff, format, FormFilename(buffer,statistic.path, COLS-10));
+  sprintf(auxbuff, format, FormFilename(buffer,statistic.path, MAXIMUM(COLS-10,0)));
   wmove( stdscr, 0, 6);
   wclrtoeol( stdscr);
   Print( stdscr, 0, 6, auxbuff, HIMENUS_COLOR);
@@ -155,7 +155,7 @@ void DisplayGlobalFileParameter(FileEntry *file_entry)
 
   (void) sprintf( format, "[%%-%ds]", COLS - 10 );
   (void) GetPath( file_entry->dir_entry, buffer1 );
-  FormFilename( buffer2, buffer1, COLS - 10 );
+  FormFilename( buffer2, buffer1, MAXIMUM(COLS - 10, 0) );
   sprintf(buffer1, format, buffer2);
   wmove( stdscr, 0, 6);
   wclrtoeol( stdscr);
