@@ -1225,3 +1225,15 @@ char *CutName(char *dest, char *src, unsigned int max_len)
 
 
 
+/*****************************************************************************
+ *                              SubString
+ *****************************************************************************/
+
+char *SubString(char *dest, char *src, int pos, int len)
+{
+  strncpy(dest, &src[pos], len);
+  dest[len] = '\0';
+  return dest;
+}
+
+
