@@ -68,6 +68,8 @@ int View(DirEntry * dir_entry, char *file_path)
     case TAR_FILE_MODE : 
     case ZOO_FILE_MODE :
     case ZIP_FILE_MODE :
+    case SEVENZIP_FILE_MODE :
+    case ISO_FILE_MODE :
     case LHA_FILE_MODE :
     case ARC_FILE_MODE : return( ViewArchiveFile( file_path ) );
     default:             beep(); return( -1 );
@@ -158,6 +160,14 @@ static int ViewFile(DirEntry * dir_entry, char *file_path)
             ERR_TO_STDOUT,
             PAGER 
           );
+    } else if( compress_method == LZIP_COMPRESS ) {
+        (void) sprintf( command_line, 
+                    "%s -dc < %s %s | %s", 
+            LUNZIP, 
+            file_p_aux, 
+            ERR_TO_STDOUT,
+            PAGER 
+          );
     } else {
         (void) sprintf( command_line, 
             "%s %s", 
@@ -995,7 +1005,9 @@ int InternalView(char *file_path)
     }
     Print( stdscr, 0, 0, "Path: ", MENU_COLOR );
     delwin(VIEW);
+    VIEW = NULL;
     delwin(BORDER);
+    BORDER = NULL;
     touchwin(stdscr);
     wnoutrefresh(stdscr);
     close(fd);
