@@ -475,10 +475,16 @@ extern char *getcwd();
 #define ZOOEXPAND       GetProfileValue( "ZOOEXPAND" )
 #define ZIPLIST         GetProfileValue( "ZIPLIST" )
 #define ZIPEXPAND       GetProfileValue( "ZIPEXPAND" )
+#define SEVENZIPLIST    GetProfileValue( "7zLIST" )
+#define SEVENZIPEXPAND  GetProfileValue( "7zEXPAND" )
+#define ISOLIST         GetProfileValue( "ISOLIST" )
+#define ISOEXPAND       GetProfileValue( "ISOEXPAND" )
+#define ZSTDCAT         GetProfileValue( "ZSTDCAT" )
 #define LHALIST         GetProfileValue( "LHALIST" )
 #define LHAEXPAND       GetProfileValue( "LHAEXPAND" )
 #define ARCLIST         GetProfileValue( "ARCLIST" )
 #define ARCEXPAND       GetProfileValue( "ARCEXPAND" )
+#define LUNZIP          GetProfileValue( "LUNZIP" )
 #define TREEDEPTH       GetProfileValue( "TREEDEPTH" )
 #define USERVIEW        GetProfileValue( "USERVIEW" )
 #define RARLIST         GetProfileValue( "RARLIST" )
@@ -504,19 +510,21 @@ extern char *getcwd();
 #define MESSAGE( msg )     Message( msg ) 
 #define NOTICE( msg )      Notice( msg ) 
 
-#define TAGGED_SYMBOL '*'
-#define MAX_MODES      11
-#define DISK_MODE      0
-#define LL_FILE_MODE   1
-#define TAR_FILE_MODE  2
-#define ZOO_FILE_MODE  3
-#define ZIP_FILE_MODE  4
-#define LHA_FILE_MODE  5
-#define ARC_FILE_MODE  6
-#define RPM_FILE_MODE  7
-#define RAR_FILE_MODE  8
-#define TAPE_MODE      9 
-#define USER_MODE      10 
+#define TAGGED_SYMBOL       '*'
+#define MAX_MODES            13
+#define DISK_MODE            0
+#define LL_FILE_MODE         1
+#define TAR_FILE_MODE        2
+#define ZOO_FILE_MODE        3
+#define ZIP_FILE_MODE        4
+#define SEVENZIP_FILE_MODE   5
+#define ISO_FILE_MODE        6
+#define LHA_FILE_MODE        7
+#define ARC_FILE_MODE        8
+#define RPM_FILE_MODE        9
+#define RAR_FILE_MODE        10
+#define TAPE_MODE            11
+#define USER_MODE            12 
 
 #define NO_COMPRESS                 0
 #define FREEZE_COMPRESS             1
@@ -530,13 +538,17 @@ extern char *getcwd();
 #define LHA_COMPRESS                9
 #define ARC_COMPRESS                10
 #define ZIP_COMPRESS                11
-#define RPM_COMPRESS                12
-#define TAPE_DIR_NO_COMPRESS        13
-#define TAPE_DIR_FREEZE_COMPRESS    14
-#define TAPE_DIR_COMPRESS_COMPRESS  15
-#define TAPE_DIR_GZIP_COMPRESS      16
-#define TAPE_DIR_BZIP_COMPRESS	    17
-#define RAR_COMPRESS                18
+#define SEVENZIP_COMPRESS           12
+#define ISO_COMPRESS                13
+#define RPM_COMPRESS                14
+#define TAPE_DIR_NO_COMPRESS        15
+#define TAPE_DIR_FREEZE_COMPRESS    16
+#define TAPE_DIR_COMPRESS_COMPRESS  17
+#define TAPE_DIR_GZIP_COMPRESS      18
+#define TAPE_DIR_BZIP_COMPRESS	    19
+#define RAR_COMPRESS                20
+#define LZIP_COMPRESS               21
+#define ZSTD_COMPRESS               22
 
 #define FILE_EXTENSIONS  {                                           \
 			   { ".TAP", TAPE_DIR_NO_COMPRESS },         \
@@ -584,7 +596,11 @@ extern char *getcwd();
 			   { ".rpm", RPM_COMPRESS },                 \
 			   { ".RPM", RPM_COMPRESS },                 \
 			   { ".spm", RPM_COMPRESS },                 \
-			   { ".SPM", RPM_COMPRESS }                  \
+			   { ".SPM", RPM_COMPRESS },                 \
+			   { ".lz",  LZIP_COMPRESS },                \
+			   { ".7z",  SEVENZIP_COMPRESS },            \
+			   { ".iso", ISO_COMPRESS },                 \
+			   { ".zst", ZSTD_COMPRESS }                 \
 			 }
 
 
@@ -922,6 +938,7 @@ extern int  ReadTreeFromTAR(DirEntry *dir_entry, FILE *f);
 extern int  ReadTreeFromRPM(DirEntry *dir_entry, FILE *f);
 extern int  ReadTreeFromZOO(DirEntry *dir_entry, FILE *f);
 extern int  ReadTreeFromZIP(DirEntry *dir_entry, FILE *f);
+extern int  ReadTreeFrom7z(DirEntry *dir_entry, FILE *f);
 extern int  ReadTreeFromLHA(DirEntry *dir_entry, FILE *f);
 extern int  ReadTreeFromARC(DirEntry *dir_entry, FILE *f);
 extern int  ReadTreeFromRAR(DirEntry *dir_entry, FILE *f);
@@ -1032,7 +1049,7 @@ extern int MakeDirectory(DirEntry *father_dir_entry);
 extern time_t Mktime(struct tm *tm);
 extern int TryInsertArchiveDirEntry(DirEntry *tree, char *dir, struct stat *stat);
 extern int InsertArchiveFileEntry(DirEntry *tree, char *path, struct stat *stat);
-extern int MinimizeArchiveTree(DirEntry *tree);
+extern void MinimizeArchiveTree(DirEntry *tree);
 extern void HitReturnToContinue(void);
 extern int  TermcapWgetch(WINDOW *win);
 extern void TermcapVidattr(int attr );
@@ -1106,3 +1123,5 @@ extern char *Strndup(const char *s, int len);
 extern char *CutName(char *dest, char *src, unsigned int max_len);
 extern int  StrCaseCmp(char *s1, char *s2);
 extern int  StrNCaseCmp(char *s1, char *s2, unsigned int n);
+extern char *SubString(char *dest, char *src, int pos, int len);
+
