@@ -21,7 +21,6 @@ int ReadTreeFromZIP(DirEntry *dir_entry, FILE *f)
   char zip_line[ZIP_LINE_LENGTH + 1];
   char path_name[PATH_LENGTH +1];
   struct stat stat;
-  BOOL   dir_flag = FALSE;
 
   *dir_entry->name = '\0';
 
@@ -32,9 +31,7 @@ int ReadTreeFromZIP(DirEntry *dir_entry, FILE *f)
 
     zip_line[ strlen( zip_line ) - 1 ] = '\0';
 
-    if( strlen( zip_line ) > (unsigned) 58 && 
-        (zip_line[56] == ':' || 
-	(zip_line[57] != 'd' && zip_line[58] == ':')))
+    if( strlen( zip_line ) > (unsigned) 58 && (zip_line[56] == ':' || (zip_line[57] != 'd' && zip_line[58] == ':')))
     {
       /* gueltiger Eintrag */
       /*-------------------*/
@@ -52,19 +49,16 @@ int ReadTreeFromZIP(DirEntry *dir_entry, FILE *f)
 #ifdef DEBUG
   fprintf( stderr, "FILE: \"%s\"\n", path_name );
 #endif
-        (void) InsertArchiveFileEntry( dir_entry, path_name, &stat );
+        if(*path_name)
+          (void) InsertArchiveFileEntry( dir_entry, path_name, &stat );
       }
     }
   } 
 
 
-  if( dir_flag == FALSE )
-  {
-    statistic.disk_total_directories++;
-    (void) memset( (char *) &dir_entry->stat_struct, 0, sizeof( struct stat ) );
-    dir_entry->stat_struct.st_mode = S_IFDIR;
-  }
-  return( MinimizeArchiveTree( dir_entry ) );
+  MinimizeArchiveTree( dir_entry );
+
+  return( 0 );
 }
 
 
@@ -76,13 +70,14 @@ static int GetStatFromZIP(char *zip_line, char *name, struct stat *stat)
   char *t, *old;
   int  i, id;
   struct tm tm_struct;
-  static char *month[] = { "Jan", "Feb", "Mar", "Apr", "Mai", "Jun",
+  static char *month[] = { "Jan", "Feb", "Mar", "Apr",  "May",  "Jun",
 	 	           "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
 
 
   (void) memset( stat, 0, sizeof( struct stat ) );
 
   stat->st_nlink = 1;
+  *name = '\0';
 
   t = Strtok_r( zip_line, " \t", &old ); if( t == NULL ) return( -1 );
 
@@ -97,12 +92,21 @@ static int GetStatFromZIP(char *zip_line, char *name, struct stat *stat)
   {
     /* DOS-Zip-File ? */
     /*----------------*/
-
-    stat->st_mode = GetModus( "-rw-rw-rw-" );
+    if(strlen(t) == 7 && *t == 'd')
+      stat->st_mode = GetModus( "drw-rw-rw-" );
+    else
+      stat->st_mode = GetModus( "-rw-rw-rw-" );
   }
+
+  if( !S_ISREG( stat->st_mode ) )
+    return 0;  /* skip non file entries */
+
   
   t = Strtok_r( NULL, " \t", &old ); if( t == NULL ) return( -1 );
 
+  if(!strcmp(t, "file,"))  /* skip summary line */
+    return 0;
+
   /* Version */
   /*---------*/
   
@@ -160,7 +164,6 @@ static int GetStatFromZIP(char *zip_line, char *name, struct stat *stat)
   t = Strtok_r( NULL, " \t:", &old ); if( t == NULL ) return( -1 );
 
   tm_struct.tm_min = atoi( t );
-  t = Strtok_r( NULL, " \t", &old ); if( t == NULL ) return( -1 );
   
   tm_struct.tm_sec = 0;
   
@@ -187,6 +190,7 @@ static int GetStatFromZIP(char *zip_line, char *name, struct stat *stat)
   /* Dateiname */
   /*-----------*/
 
+  t = Strtok_r( NULL, "", &old ); if( t == NULL ) return( -1 ); /* ...to end of line */
   (void) strcpy( name, t );
 
   return( 0 );
